import { Identifiable, Identifier, Internship } from "@/data";
import { sampleCompanies, sampleStudent } from "@/provider/dummy";
import moment, { Moment } from "moment-timezone";
import { OneOrMany } from "@/helpers";
import { SubmissionState, SubmissionStatus } from "@/state/reducer/submission";

export type InternshipSubmission = Internship & {
    state: SubmissionStatus,
    changed: Moment
}

const sampleInternship: InternshipSubmission = {
    id: "test",
    company: sampleCompanies[0],
    startDate: moment('2020-07-01'),
    endDate: moment('2020-08-31'),
    hours: 180,
    intern: sampleStudent,
    isAccepted: false,
    lengthInWeeks: 0,
    mentor: {
        email: "test@test.com",
        name: "Test",
        surname: "Testowy",
        phone: "+48 123 456 789"
    },
    office: sampleCompanies[0].offices[0],
    program: [
        { description: "Test" },
    ],
    type: {
        description: {
            pl: "Przykładowy typ",
            en: "Example type"
        },
        label: {
            pl: "Przykładowy",
            en: "Example"
        },
        requiresDeanApproval: true,
        requiresInsurance: false
    },
    state: "declined",
    changed: moment(),
}

export async function all(edition: Identifiable): Promise<InternshipSubmission[]> {
    return [
        sampleInternship,
    ]
}

export async function get(id: Identifier): Promise<InternshipSubmission> {
    return sampleInternship;
}

export async function approve(internship: OneOrMany<Internship>, comment?: string): Promise<void> {}
export async function decline(internship: OneOrMany<Internship>, comment: string): Promise<void> {}
