import React, { useCallback } from "react";
import { Link as RouterLink, useRouteMatch } from "react-router-dom";
import api from "@/management/api";
import { Page } from "@/pages/base";
import { EditionManagement, EditionManagementProps } from "@/management/edition/manage";
import { Container, Link, Typography } from "@material-ui/core";
import { Async } from "@/components/async";
import { useTranslation } from "react-i18next";
import { useAsync } from "@/hooks";
import { Student } from "@/data";
import { route } from "@/routing";
import { ProposalPreview } from "@/components/proposalPreview";
import { AcceptanceActions } from "@/components/acceptance-action";
import { useSpacing } from "@/styles";

const fullname = (student: Student) => `${student.name} ${student.surname}`;

export const InternshipDetails = ({ edition }: EditionManagementProps) => {
    const { params } = useRouteMatch();
    const internship = useAsync(useCallback(() => api.internship.get(params.internship), [ params.internship ]));
    const { t } = useTranslation("management");
    const spacing = useSpacing(2);

    return <Async async={ internship }>
        { internship => <Page>
            <Page.Header maxWidth="lg">
                <EditionManagement.Breadcrumbs>
                    <Link to={ route("management:edition_internships", { edition: edition.id || "" }) } component={ RouterLink }>{ t("edition.internships.title") }</Link>
                    <Typography color="textPrimary">{ fullname(internship.intern) }</Typography>
                </EditionManagement.Breadcrumbs>
                <Page.Title>{ fullname(internship.intern) }</Page.Title>
            </Page.Header>
            <Container maxWidth="lg" className={ spacing.vertical }>
                <ProposalPreview proposal={ internship } />
                <AcceptanceActions onAccept={ () => {} } onDiscard={ () => {} } label="internship" />
            </Container>
        </Page> }
    </Async>
}
